/*
* GLOBAL VARIABLES
*/
variable "stack_name" {
  description = "The name of the stack, applied as a tag to all resources"
  default     = "perforce"
}

variable "aws_region" {
  description = "AWS Region"
  default     = "eu-west-1"
}

variable "env" {
  description = "The environment, e.g. stage, dev, production (this changes some resources, e.g. multi NAT gateway or MultiAZ in case of production)"
  default     = "dev"
}

variable "owner" {
  description = "The owner of this stack"
}

/*
* NETWORK
*/

module "networking" {
  source = "./networking"
  cidr   = "10.0.0.0/16"

  "az-subnet-mapping" = [
    {
      name = "subnet1"
      az   = "eu-west-1a"
      cidr = "10.0.0.0/24"
    },
    // {
    //   name = "subnet2"
    //   az   = "eu-west-1c"
    //   cidr = "10.0.1.0/24"
    // },
  ]
}

variable "key_name" {
  description = "Name of the public key used for SSH, will be uploaded from ./files/key_name.pem"
}

variable "additional_public_keys" {
  description = "A list of additional public keys to inject (bastion only)"
  default     = []
  type        = "list"
}

variable "instance_type" {
  default = "t2.small"
  type    = "string"
}

// If we have a certificate to assign
// variable "certificate_arn" {
//   type = "string"
// }

// variable "public_hosted_zone_name" {
//   type        = "string"
//   description = "The name of the public hosted zone the services will run in, must already exist"
// }
